@@ -4,6 +4,8 @@
 #include <config.h>
 #endif
 
+#include <unistd.h>
+
 #include <arc/compute/TestACCControl.h>
 
 #include "JobListRetrieverPluginTEST.h"
@@ -14,7 +16,7 @@ EndpointQueryingStatus JobListRetrieverPluginTEST::Query(const UserConfig&,
                                                           const Endpoint&,
                                                           std::list<Job>& jobs,
                                                           const EndpointQueryOptions<Job>&) const {
-  Glib::usleep(JobListRetrieverPluginTESTControl::delay*1000000);
+  usleep(JobListRetrieverPluginTESTControl::delay*1000000);
   jobs = JobListRetrieverPluginTESTControl::jobs;
   return JobListRetrieverPluginTESTControl::status;
 };
